/*
 * file CqDynamicChoiceList.java
 *
 * Licensed Materials - Property of IBM
 * Restricted Materials of IBM 
 *
 * com.ibm.rational.wvcm.stp.cq.CqDynamicChoiceList
 *
 *  Copyright IBM Corporation 2004, 2008.  All Rights Reserved.
 * Note to U.S. Government Users Restricted Rights:  Use, duplication or 
 * disclosure restricted by GSA ADP  Schedule Contract with IBM Corp.
 */

package com.ibm.rational.wvcm.stp.cq;

import static com.ibm.rational.wvcm.stpex.StpExBase.PROPERTY_NAMESPACE;

import java.util.List;

import javax.wvcm.WvcmException;
import javax.wvcm.PropertyNameList.PropertyName;

import com.ibm.rational.wvcm.stp.StpResource;
import com.ibm.rational.wvcm.stpex.StpExBase;

/**
 * A proxy for a ClearQuest dynamic choice list.
 *  * <p>
 * The user-friendly specification for the location of a dynamic choice list has the form
 * <pre>
 *  <b>cq.choicelist:</b><i>&lt;choice-list-name&gt;</i>@<i>&lt;db-set&gt;</i>/<i>&lt;user-db&gt;</i>
 * </pre>
 */
public interface CqDynamicChoiceList 
    extends CqContextResource {
    
    /** The list of choices in this dynamic choice list */
    public static final PropertyName<List<String>> MEMBER_LIST =
        new PropertyName<List<String>>(PROPERTY_NAMESPACE, "member-list");

    /**
     * Returns the value of the {@link #MEMBER_LIST MEMBER_LIST} property as
     * defined by this proxy. If this property was set in the proxy via
     * {@link #setMemberList(List, List)}, only the list of additions will be
     * returned
     * 
     * @return A list of Strings each representing one member of the choice list
     * 
     * @throws WvcmException if this proxy does not define a value for the
     *             {@link #MEMBER_LIST MEMBER_LIST} property.
     */
    public List<String> getMemberList() throws WvcmException;

    /**
     * Defines values for the {@link #MEMBER_LIST MEMBER_LIST} property of this
     * proxy.
     * 
     * @param choices A list of Strings specifying the members of this dynamic
     *            choice list. This list becomes the entire new content of the
     *            dynamic choice list. In a highly collaborative environment,
     *            updating the list in this fashion is discouraged. Use
     *            {@link #setMemberList(List, List)} instead.
     */
    public void setMemberList(List<String> choices);

    /**
     * Establishes the values to be added to and/or deleted from the MEMBER_LIST
     * property when that property is updated from this proxy (via
     * doWriteProperties or any other "do" method of this interface).
     * 
     * @param additions The list of String values that must be in the
     *            MEMBER_LIST property after it has been updated from this
     *            proxy. Thus, it is OK for a value in this list to already be a
     *            member of the property value. This list may be empty or null
     *            if no values are to be added to the property. A value may not
     *            appear in both this list and the deletions list.
     * 
     * @param deletions The list of String values that must not be in the
     *            MEMBER_LIST property after it has been updated from this
     *            proxy. Thus, it is OK for a value in this list to not be a
     *            current member of the property value. This list may be empty
     *            or null if no values are to be deleted from the property. A
     *            value may not appear in both this list and the additions list.
     */
    void setMemberList(List<String> additions,
                       List<String> deletions);
}
