/*
 * file CqResource.java
 * 
 * Licensed Materials - Property of IBM
 * Restricted Materials of IBM 
 *
 * com.ibm.rational.wvcm.stp.cq.CqResource
 *
 *  Copyright IBM Corporation 2004, 2008.  All Rights Reserved.
 * Note to U.S. Government Users Restricted Rights:  Use, duplication or 
 * disclosure restricted by GSA ADP  Schedule Contract with IBM Corp.
 */

package com.ibm.rational.wvcm.stp.cq;

import java.util.Date;
import java.util.List;
import java.util.Locale;

import javax.wvcm.Folder;
import javax.wvcm.ResourceList;
import javax.wvcm.Workspace;
import javax.wvcm.WvcmException;

import com.ibm.rational.wvcm.stp.StpResource;
import com.ibm.rational.wvcm.stp.StpException.StpReasonCode;

/**
 * Properties and methods common to all ClearQuest resources
 */
public interface CqResource extends StpResource
{
    /**
     * @return Returns the CqProvider from which this proxy was obtained.
     */
    CqProvider cqProvider();

    /**
     * Most ClearQuest resources <i>do not</i> support the COMMENT property
     * @see javax.wvcm.Resource#getComment()
     */
    @UnsupportedProperty(StpReasonCode.PROPERTY_NOT_SUPPORTED_BY_SERVER)
    String getComment() throws WvcmException;

    /**
     * Most ClearQuest resources <i>do not</i> support the COMMENT property
     * @see javax.wvcm.Resource#setComment(java.lang.String)
     */
    @UnsupportedProperty(StpReasonCode.PROPERTY_OVERWRITE_FORBIDDEN)
    void setComment(String value);

    /**
     * Most ClearQuest resources <i>do not</i> have content and therefore <i>do not</i> support
     * the CONTENT_LENGTH property
     * 
     * @see javax.wvcm.Resource#getContentLength()()
     */

    @UnsupportedProperty(StpReasonCode.PROPERTY_NOT_SUPPORTED_BY_SERVER)
    long getContentLength() throws WvcmException;

    /**
     * Most ClearQuest resources <i>do not</i> have content and therefore <i>do not</i>
     * support the CONTENT_CHARACTER_SET property
     * 
     * @see javax.wvcm.Resource#getContentCharacterSet()()
     */
    @UnsupportedProperty(StpReasonCode.PROPERTY_NOT_SUPPORTED_BY_SERVER)
    String getContentCharacterSet() throws WvcmException;

    /**
     * Most ClearQuest resources <i>do not</i> have content and therefore <i>do not</i>
     * support the CONTENT_CHARACTER_SET property
     * 
     * @see javax.wvcm.Resource#setContentCharacterSet(java.lang.String)
     */
    @UnsupportedProperty(StpReasonCode.PROPERTY_OVERWRITE_FORBIDDEN)
    void setContentCharacterSet(String value);

    /**
     * Most ClearQuest resources <i>do not</i> have content and therefore <i>do not</i>
     * support the CONTENT_IDENTIFIER property
     * 
     * @see javax.wvcm.Resource#getContentIdentifier()()
     */

    @UnsupportedProperty(StpReasonCode.PROPERTY_NOT_SUPPORTED_BY_SERVER)
    String getContentIdentifier() throws WvcmException;

    /**
     * Most ClearQuest resources <i>do not</i> have content and therefore <i>do not</i>
     * support the CONTENT_LANGUAGE property
     * 
     * @see javax.wvcm.Resource#getContentLanguage()
     */

    @UnsupportedProperty(StpReasonCode.PROPERTY_NOT_SUPPORTED_BY_SERVER)
    Locale getContentLanguage() throws WvcmException;

    /**
     * Most ClearQuest resources <i>do not</i> have content and therefore <i>do not</i>
     * support the CONTENT_LANGUAGE property
     * 
     * @see javax.wvcm.Resource#setContentLanguage(java.util.Locale)
     */
    @UnsupportedProperty(StpReasonCode.PROPERTY_OVERWRITE_FORBIDDEN)
    void setContentLanguage(Locale value);

    /**
     * Most ClearQuest resources <i>do not</i> have content and therefore <i>do not</i> support
     * the CONTENT_TYPE property
     * 
     * @see javax.wvcm.Resource#getContentType()()
     */
    @UnsupportedProperty(StpReasonCode.PROPERTY_NOT_SUPPORTED_BY_SERVER)
    String getContentType() throws WvcmException;

    /**
     * Most ClearQuest resources <i>do not</i> have content and therefore <i>do not</i> support
     * the CONTENT_TYPE property
     * @see javax.wvcm.Resource#setContentType(java.lang.String)
     */
    @UnsupportedProperty(StpReasonCode.PROPERTY_OVERWRITE_FORBIDDEN)
    void setContentType(String value);

    /**
     * Most ClearQuest resources <i>do not</i> have content and therefore <i>do not</i>
     * support the CREATION_DATE property
     * 
     * @see javax.wvcm.Resource#getCreationDate()()
     */

    @UnsupportedProperty(StpReasonCode.PROPERTY_NOT_SUPPORTED_BY_SERVER)
    Date getCreationDate() throws WvcmException;

    /**
     * Most ClearQuest resources <i>do not</i> have content and therefore <i>do not</i>
     * support the CREATOR_DISPLAY_NAME property
     * 
     * @see javax.wvcm.Resource#getCreatorDisplayName()
     */

    @UnsupportedProperty(StpReasonCode.PROPERTY_NOT_SUPPORTED_BY_SERVER)
    String getCreatorDisplayName() throws WvcmException;

    /**
     * Most ClearQuest resources <i>do not</i> have content and therefore <i>do not</i>
     * support the CREATOR_DISPLAY_NAME property
     * @see javax.wvcm.Resource#setCreatorDisplayName(java.lang.String)
     */
    @UnsupportedProperty(StpReasonCode.PROPERTY_OVERWRITE_FORBIDDEN)
    void setCreatorDisplayName(String value);

    /**
     * Most ClearQuest resources <i>do not</i> have content and therefore <i>do not</i>
     * support the CREATOR_GROUP_NAME property
     * 
     * @see com.ibm.rational.wvcm.stp.StpResource#getCreatorGroupName()
     */

    @UnsupportedProperty(StpReasonCode.PROPERTY_NOT_SUPPORTED_BY_SERVER)
    String getCreatorGroupName() throws WvcmException;

    /**
     * Most ClearQuest resources <i>do not</i> have content and therefore <i>do not</i>
     * support the CREATOR_LOGIN_NAME property
     * 
     * @see com.ibm.rational.wvcm.stp.StpResource#getCreatorLoginName()
     */

    @UnsupportedProperty(StpReasonCode.PROPERTY_NOT_SUPPORTED_BY_SERVER)
    String getCreatorLoginName() throws WvcmException;

    /**
     * Most ClearQuest resources <i>do not</i> have content and therefore <i>do not</i>
     * support the LAST_MODIFIED property
     * 
     * @see javax.wvcm.Resource#getLastModified()
     */

    @UnsupportedProperty(StpReasonCode.PROPERTY_NOT_SUPPORTED_BY_SERVER)
    Date getLastModified() throws WvcmException;

    /**
     * <i>No</i> ClearQuest resources is executable
     * 
     * @see javax.wvcm.Resource#getIsExecutable()
     */

    @UnsupportedProperty(StpReasonCode.PROPERTY_NOT_SUPPORTED_BY_SERVER)
    Boolean getIsExecutable() throws WvcmException;

    /**
     * <i>No</i> ClearQuest resource is executable
     * 
     * @see javax.wvcm.Resource#getIsExecutable()
     */
    @UnsupportedProperty(StpReasonCode.PROPERTY_NOT_SUPPORTED_BY_SERVER)
    void setIsExecutable(Boolean executable);
    
    /**
     * ClearQuest resources do not use workspaces.
     * @see javax.wvcm.Resource#getWorkspaceFolderList()
     */
    @UnsupportedProperty(StpReasonCode.PROPERTY_NOT_SUPPORTED_BY_SERVER)
    ResourceList<Folder> getWorkspaceFolderList() throws WvcmException;
    
    /**
     * @see javax.wvcm.Resource#getWorkspaceFolderList()
     */
    @UnsupportedProperty(StpReasonCode.PROPERTY_NOT_SUPPORTED_BY_SERVER)
    List<String> getProviderList() throws WvcmException;
}
